# Getting Started

Included within this directory are a set of example Jupyter notebooks. These notebooks will cover the functionality contained in the client for creating and interacting with Oqtant jobs.

- [Walkthrough #1 BEC Jobs](walkthrough_1_bec_jobs.md)
- [Walkthrough #2 BARRIER Jobs](walkthrough_2_barrier_jobs.md)
- [Walkthrough #3 Abstractions](walkthrough_3_abstractions.md)
- [Walkthrough #4 Experiments](walkthrough_4_experiments.md)
- [Walkthrough #5 Optimization](walkthrough_5_optimization.md)
